# Change History

## 2021.10.24

* Intermediate release with new dev tools
* Changed name of package will deal with depreaction of the package under the old name [`purge_range`](https://pypi.org/project/purge-range/) later.
* Followed the name change of upstream [`prefix_compression`](https://pypi.org/project/prefix-compression/) package to [`puristaa`](https://pypi.org/project/puristaa/)
* No functional changes

## 0.0.2 (2021-05-13)

* Second release on PyPI as purge_range

## 0.0.1 (2021-05-08)

* Initial release on PyPI as purge_range

